@@ -1,5 +1,5 @@
-$DEF_VERSION = $VERSION_D = "0.2.10";
-$version_key = "Bucktooth/0.2.9";
+$VERSION_D = "0.1PR4";
+$version_key = "Bucktooth/0.1pr4";
 $my_version_key = 0;
 
 sub detaint { # sigh
@@ -32,9 +32,9 @@ sub wherecheck {
 
 	print stdout "$prompt ... ";
 	foreach(@paths) {
-		$setv = "$_/$filename";
-		1 while $setv =~ s#//#/#;
-		if (-r $setv) {
+		if (-r "$_/$filename") {
+			$setv = "$_/$filename";
+			1 while $setv =~ s#//#/#;
 			print "$setv\n";
 			last;
 		}
